@@ -1,5 +1,6 @@
 from typing import Dict, List
 
+from ..managers import PlayMoneyPortfolioManager
 from ..indicators import AbstractIndicator
 from ..domain import Strategy, Portfolio, SimulationDataset, Pitch
 from ..engines import PortfolioWrapper
@@ -10,16 +11,17 @@ class PitchSimulator(object):
         self.data = dataset.data
         self.test_data = dataset.test_data
 
-    def run(self, indicators: List[AbstractIndicator], strategies: List[Strategy], portfolio: Portfolio = Portfolio()):
+    def run(self, indicators: List[AbstractIndicator], strategies: List[Strategy]):
+        portfolio_manager = PlayMoneyPortfolioManager(Portfolio())
+
         engine = PortfolioWrapper(
             self.data,
             indicators,
             strategies,
-            portfolio,
-            paper_money=True,
+            portfolio_manager
         )
 
         for _, stock_prices in self.test_data.items():
             engine.run(Pitch(stock_prices))
 
-        return engine.strategy_operations
+        return portfolio_manager.strategy_operations
